@@ -9,7 +9,7 @@ function prepare_file_object(table_object) {
         'oread': null,
         'owrite': null,
         'oexec': null
-    }
+    };
     var new_table_object = {};
     Object.keys(table_object).forEach(key => {
         if (key in permission) {
@@ -92,12 +92,10 @@ function create_table(table_object) {
 function show_object(obj) {
     if (Object.values(obj).includes("complete")) {
         $("#content").append("<p>Following items have been found on the system:</p>");
-        create_table(obj);
     } else {
         $("#content").append("<p>No items have been found conforming to the following objects:<br>" +
             "Object <b>" + Object.keys(obj)[0] +
             "</b> of type <b>" + Object.keys(obj)[1] + "</b></p>");
-        create_table(obj);
     }
 }
 
@@ -110,7 +108,10 @@ function open_modal(data) {
         "<span class=\"label label-default\">" + data.id + "</span>" +
         data.result
     );
-    data.objects.forEach(show_object);
+    data.objects.forEach(object => {
+        show_object(object);
+        create_table(object);
+    });
 }
 
 function show_graph(id, data) {
@@ -143,3 +144,16 @@ jQuery.each(data, function (rule, data) {
     rule_id = "#" + rule.replace(/[\_\-\.]/g, "");
     show_graph(rule_id, data);
 });
+
+function search() {
+    var input = document.getElementById("Search");
+    var filter = input.value.toLowerCase();
+    var nodes = document.getElementsByClassName('target');
+    Array.from(document.getElementsByClassName('target')).forEach(function (node) {
+        if (node.children.item(0).innerText.toLowerCase().includes(filter)) {
+            node.style.display = "block";
+        } else {
+            node.style.display = "none";
+        }
+    });
+}
